@@ -1,5 +1,10 @@
 package ipmi
 
+import (
+	"errors"
+	"fmt"
+)
+
 // Command is the field in an IPMI message
 type Command struct {
 	ID    uint8
@@ -11,7 +16,6 @@ type Request interface {
 	// Pack encodes the object to data bytes
 	Pack() []byte
 	// Command return the IPMI command info (NetFn/Cmd).
-	// All IPMI specification specified commands are already predefined in this file.
 	Command() Command
 }
 
@@ -39,13 +43,24 @@ type ResponseError struct {
 
 // Error implements the error interface
 func (e *ResponseError) Error() string {
-	return e.description
+	return fmt.Sprintf("cc: %#02x, description: %s", uint8(e.completionCode), e.description)
 }
 
 func (e *ResponseError) CompletionCode() CompletionCode {
 	return e.completionCode
 }
 
+func isResponseError(err error) (respErr *ResponseError, ok bool) {
+	if err == nil {
+		return nil, false
+	}
+
+	if errors.As(err, &respErr) {
+		return respErr, true
+	}
+	return nil, false
+}
+
 // Appendix G - Command Assignments
 // Command Number Assignments (Appendix G, table G-1)
 var (
@@ -68,8 +83,8 @@ var (
 	CommandGetConfigurableCommandSubfunctions = Command{ID: 0x0d, NetFn: NetFnAppRequest, Name: "Get Configurable Command Sub-functions"} // 0Eh - 0Fh reserved
 	CommandSetCommandEnables                  = Command{ID: 0x60, NetFn: NetFnAppRequest, Name: "Set Command Enables"}
 	CommandGetCommandEnables                  = Command{ID: 0x61, NetFn: NetFnAppRequest, Name: "Get Command Enables"}
-	CommandSetCommandSubfunctionsEnables      = Command{ID: 0x62, NetFn: NetFnAppRequest, Name: "Set Command Sub-function Enables"}
-	CommandGetCommandSubfunctionsEnables      = Command{ID: 0x63, NetFn: NetFnAppRequest, Name: "Get Command Sub-function Enables"}
+	CommandSetCommandSubfunctionEnables       = Command{ID: 0x62, NetFn: NetFnAppRequest, Name: "Set Command Sub-function Enables"}
+	CommandGetCommandSubfunctionEnables       = Command{ID: 0x63, NetFn: NetFnAppRequest, Name: "Get Command Sub-function Enables"}
 	CommandGetOEMNetFnIanaSupport             = Command{ID: 0x64, NetFn: NetFnAppRequest, Name: "Get OEM NetFn IANA Support"}
 
 	// BMC Watchdog Timer Commands
@@ -116,8 +131,8 @@ var (
 	CommandGetChannelOEMPayloadInfo       = Command{ID: 0x50, NetFn: NetFnAppRequest, Name: "Get Channel OEM Payload Info"} // 51 unassigned
 	CommandMasterWriteRead                = Command{ID: 0x52, NetFn: NetFnAppRequest, Name: "Master Write-Read"}            // 53 unassigned
 	CommandGetChannelCipherSuites         = Command{ID: 0x54, NetFn: NetFnAppRequest, Name: "Get Channel Cipher Suites"}
-	CommandSuspendOrResumeEncryption      = Command{ID: 0x55, NetFn: NetFnAppRequest, Name: "Suspend/Resume Payload Encryption"}
-	CommandSetChannelCipherSuites         = Command{ID: 0x56, NetFn: NetFnAppRequest, Name: "Set Channel Security Keys"}
+	CommandSuspendResumePayloadEncryption = Command{ID: 0x55, NetFn: NetFnAppRequest, Name: "Suspend/Resume Payload Encryption"}
+	CommandSetChannelSecurityKeys         = Command{ID: 0x56, NetFn: NetFnAppRequest, Name: "Set Channel Security Keys"}
 	CommandGetSystemInterfaceCapabilities = Command{ID: 0x57, NetFn: NetFnAppRequest, Name: "Get System Interface Capabilities"}
 
 	// Chassis Device Commands
