@@ -1,12 +1,9 @@
 package ipmi
 
 import (
-	"bytes"
 	"fmt"
 	"math"
 	"strings"
-
-	"github.com/olekukonko/tablewriter"
 )
 
 // 42.1
@@ -874,6 +871,8 @@ func ConvertSensorTolerance(raw uint8, analogDataFormat SensorAnalogUnitFormat,
 
 // Sensor holds all attribute of a sensor.
 type Sensor struct {
+	GeneratorID GeneratorID
+
 	Number uint8
 	Name   string
 
@@ -889,8 +888,9 @@ type Sensor struct {
 	EntityID       EntityID
 	EntityInstance EntityInstance
 
-	scanningDisabled bool // update by GetSensorReading
-	readingAvailable bool // update by GetSensorReading
+	notPresent       bool // update by GetSensorReading (CompletionCodeRequestedDataNotPresent)
+	scanningDisabled bool // update by GetSensorReadingResponse
+	readingAvailable bool // update by GetSensorReadingResponse
 
 	// Raw reading value before conversion
 	Raw uint8
@@ -944,12 +944,20 @@ type Sensor struct {
 func (s *Sensor) String() string {
 	sensorReadingRawStr := fmt.Sprintf("%d", s.Raw)
 	sensorReadingValueStr := fmt.Sprintf("%.3f %s", s.Value, s.SensorUnit)
-	if s.scanningDisabled {
-		sensorReadingRawStr = "Unable to read sensor: Device Not Present"
-		sensorReadingValueStr = "Unable to read sensor: Device Not Present"
+
+	if s.notPresent {
+		sensorReadingRawStr = "No Reading (Not Present)"
+		sensorReadingValueStr = "No Reading (Not Present)"
 	}
 
-	return fmt.Sprintf("Sensor ID              : %s (%#02x)\n", s.Name, s.Number) +
+	if s.scanningDisabled {
+		sensorReadingRawStr = "No Reading (Scanning Disabled)"
+		sensorReadingValueStr = "No Reading (Scanning Disabled)"
+	}
+
+	return "" +
+		fmt.Sprintf("Sensor ID             : %s (%#02x)\n", s.Name, s.Number) +
+		fmt.Sprintf(" Generator ID         : %#04x, %s\n", uint16(s.GeneratorID), s.GeneratorID.String()) +
 		fmt.Sprintf(" Entity ID            : %d.%d (%s)\n", uint8(s.EntityID), uint8(s.EntityInstance), s.EntityID) +
 		fmt.Sprintf(" Sensor Type          : %s (%#02x) (%s)\n", s.SensorType.String(), uint8(s.SensorType), string(s.EventReadingType.SensorClass())) +
 		fmt.Sprintf(" Sensor Number        : %#02x\n", s.Number) +
@@ -962,11 +970,43 @@ func (s *Sensor) String() string {
 
 // FormatSensors return a string of table printed for sensors
 func FormatSensors(extended bool, sensors ...*Sensor) string {
+	rows := make([]map[string]string, len(sensors))
 
-	var buf = new(bytes.Buffer)
-	table := tablewriter.NewWriter(buf)
-	table.SetAutoWrapText(false)
-	table.SetAlignment(tablewriter.ALIGN_RIGHT)
+	for i, sensor := range sensors {
+		discreteEvents := ""
+		if sensor.IsThreshold() {
+			discreteEvents = "N/A"
+		} else {
+			discreteEvents = fmt.Sprintf("%v", sensor.DiscreteActiveEvents())
+		}
+
+		row := map[string]string{
+			"SDRType":          sensor.SDRRecordType.String(),
+			"SensorNumber":     fmt.Sprintf("%#02x", sensor.Number),
+			"SensorName":       sensor.Name,
+			"SensorType":       fmt.Sprintf("%s (%#02x)", sensor.SensorType.String(), uint8(sensor.SensorType)),
+			"Reading":          sensor.ReadingStr(),
+			"Unit":             sensor.SensorUnit.String(),
+			"Status":           sensor.Status(),
+			"LNR":              sensor.ThresholdStr(SensorThresholdType_LNR),
+			"LCR":              sensor.ThresholdStr(SensorThresholdType_LCR),
+			"LNC":              sensor.ThresholdStr(SensorThresholdType_LNC),
+			"UNC":              sensor.ThresholdStr(SensorThresholdType_UNC),
+			"UCR":              sensor.ThresholdStr(SensorThresholdType_UCR),
+			"UNR":              sensor.ThresholdStr(SensorThresholdType_UNR),
+			"EntityID":         fmt.Sprintf("%s (%#02x)", sensor.EntityID, uint8(sensor.EntityID)),
+			"EventReadingType": fmt.Sprintf("%s (%#02x)", sensor.EventReadingType.String(), uint8(sensor.EventReadingType)),
+			"AnalogDataFormat": sensor.SensorUnit.AnalogDataFormat.String(),
+			"ReadV":            fmt.Sprintf("%v", sensor.IsReadingValid()),
+			"ScanD":            fmt.Sprintf("%v", sensor.scanningDisabled),
+			"ReadU":            fmt.Sprintf("%v", !sensor.readingAvailable),
+			"HasAR":            fmt.Sprintf("%v", sensor.HasAnalogReading),
+			"DiscreteEvents":   discreteEvents,
+			"HumanStr":         sensor.HumanStr(),
+		}
+
+		rows[i] = row
+	}
 
 	headers := []string{
 		"SDRType",
@@ -998,53 +1038,7 @@ func FormatSensors(extended bool, sensors ...*Sensor) string {
 		}...)
 	}
 
-	table.SetHeader(headers)
-	table.SetFooter(headers)
-
-	for _, sensor := range sensors {
-		rowContent := []string{
-			sensor.SDRRecordType.String(),
-			fmt.Sprintf("%#02x", sensor.Number),
-			sensor.Name,
-			fmt.Sprintf("%s (%#02x)", sensor.SensorType.String(), uint8(sensor.SensorType)),
-			sensor.ReadingStr(),
-			sensor.SensorUnit.String(),
-			sensor.Status(),
-			sensor.ThresholdStr(SensorThresholdType_LNR),
-			sensor.ThresholdStr(SensorThresholdType_LCR),
-			sensor.ThresholdStr(SensorThresholdType_LNC),
-			sensor.ThresholdStr(SensorThresholdType_UNC),
-			sensor.ThresholdStr(SensorThresholdType_UCR),
-			sensor.ThresholdStr(SensorThresholdType_UNR),
-		}
-
-		if extended {
-			rowContent = append(rowContent, []string{
-				fmt.Sprintf("%s (%#02x)", sensor.EntityID, uint8(sensor.EntityID)),
-				fmt.Sprintf("%s (%#02x)", sensor.EventReadingType.String(), uint8(sensor.EventReadingType)),
-				sensor.SensorUnit.AnalogDataFormat.String(),
-				fmt.Sprintf("%v", sensor.IsReadingValid()),
-				fmt.Sprintf("%v", sensor.scanningDisabled),
-				fmt.Sprintf("%v", !sensor.readingAvailable),
-				fmt.Sprintf("%v", sensor.HasAnalogReading),
-			}...)
-
-			if sensor.IsThreshold() {
-				rowContent = append(rowContent, "N/A")
-
-			} else {
-				rowContent = append(rowContent, fmt.Sprintf("%v", sensor.DiscreteActiveEvents()))
-			}
-			rowContent = append(rowContent, sensor.HumanStr())
-
-		}
-
-		table.Append(rowContent)
-	}
-
-	table.Render()
-
-	return buf.String()
+	return RenderTable(headers, rows)
 }
 
 // IsThreshold returns whether the sensor is threshold sensor class or not.
@@ -1144,6 +1138,10 @@ func (sensor *Sensor) SensorThreshold(thresholdType SensorThresholdType) SensorT
 	}
 }
 func (sensor *Sensor) Status() string {
+	if sensor.notPresent {
+		return "N/A"
+	}
+
 	if sensor.scanningDisabled {
 		return "N/A"
 	}
@@ -1159,7 +1157,12 @@ func (sensor *Sensor) Status() string {
 	return fmt.Sprintf("0x%02x%02x", sensor.Discrete.optionalData1, sensor.Discrete.optionalData2)
 }
 
+// HumanStr returns the human-readable string of the sensor.
 func (sensor *Sensor) HumanStr() string {
+	if sensor.notPresent {
+		return "N/A"
+	}
+
 	if sensor.scanningDisabled {
 		return "N/A"
 	}
@@ -1175,7 +1178,13 @@ func (sensor *Sensor) HumanStr() string {
 	return strings.Join(sensor.DiscreteActiveEventsString(), ", ")
 }
 
+// ReadingStr returns the reading value of the sensor.
+// The reading value is converted and aligned with the sensor unit, but the unit is not included in the string.
 func (sensor *Sensor) ReadingStr() string {
+	if sensor.notPresent {
+		return "N/A"
+	}
+
 	if sensor.scanningDisabled {
 		return "N/A"
 	}
@@ -1251,6 +1260,10 @@ func (sensor *Sensor) DiscreteActiveEvents() []uint8 {
 }
 
 func (sensor *Sensor) DiscreteActiveEventsString() []string {
+	if sensor.IsThreshold() {
+		return []string{"N/A"}
+	}
+
 	result := make([]string, 0)
 
 	for _, eventOffset := range sensor.DiscreteActiveEvents() {
